@@ -151,32 +151,24 @@ class LoadMaster(HttpClient):
         response = self._get("/listvs")
         data = get_data(response)
         virtual_services = []
-        try:
-            for service in data['VS']:
-                virt_serv = VirtualService(self.get_loadmaster_info,
-                                           service.get('VSAddress', None),
-                                           service.get('VSPort'),
-                                           service.get('Protocol'))
-                virt_serv.status = service.get('Status', None)
-                virt_serv.index = service.get('Index', None)
-                virt_serv.enable = service.get('Enable', None)
-                virt_serv.forcel7 = service.get('ForceL7', None)
-                virt_serv.vstype = service.get('VStype', None)
-                virt_serv.schedule = service.get('Schedule', None)
-                virt_serv.nickname = service.get('NickName', None)
-                virtual_services.append(virt_serv)
-        except KeyError:
-            return virtual_services
+        for service in data.get('VS', []):
+            virt_serv = self.build_virtual_service(service)
+            virtual_services.append(virt_serv)
+        return virtual_services
 
     def get_virtual_service(self, index=None, address=None, port=None,
                             protocol=None):
         if index is None:
             service_id = {"vs": address, "port": port, "prot": protocol}
-            response = self._get("/showvs", service_id)
         else:
             service_id = {"vs": index}
-            response = self._get("/showvs", service_id)
+        response = self._get("/showvs", service_id)
         service = get_data(response)
+        virt_serv = self.build_virtual_service(service)
+        return virt_serv
+
+    def build_virtual_service(self, service):
+        """Create a VirtualService instance with standard defaults"""
         virt_serv = VirtualService(self.get_loadmaster_info,
                                    service.get('VSAddress', None),
                                    service.get('VSPort'),
@@ -343,13 +335,11 @@ class LoadMaster(HttpClient):
 
 
 class KempBaseObjectModel(object):
-    def __init__(self):
-        # blacklist attributes that shouldn't be pushed to the loadmaster.
-        self._api_ignore = [
-            "ip_address",
-            "endpoint",
-            "endpoint",
-        ]
+    # blacklist attributes that shouldn't be pushed to the loadmaster.
+    _API_IGNORE = (
+        "ip_address",
+        "endpoint",
+    )
 
     def __repr__(self):
         return '{} {}'.format(self.__class__.__name__, self.to_api_dict())
@@ -360,11 +350,11 @@ class KempBaseObjectModel(object):
         Ignores attributes listed in _api_ignore and also attributes
         beginning with an underscore (_). Also ignore values of None"""
         api_dict = {}
-        for key in self.__dict__.keys():
-            if (key in self._api_ignore or key.startswith("_") or
-                    self.__dict__[key] is None):
+        for key, value in self.__dict__.items():
+            if (key in self._API_IGNORE or key.startswith("_") or
+                    value is None):
                 continue
-            api_dict[key] = self.__dict__[key]
+            api_dict[key] = value
         return api_dict
 
 
@@ -442,6 +432,19 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             response = self._get("/showrs", server_id)
         response_data = get_data(response)
         server = response_data["Rs"]
+        real_server = self.build_real_server(server)
+        return real_server
+
+    def get_real_servers(self):
+        response = self._get("/showvs", self._get_base_parameters())
+        data = get_data(response)
+        real_servers = []
+        for server in data.get('Rs', []):
+            real_server = self.build_real_server(server)
+            real_servers.append(real_server)
+        return real_servers
+
+    def build_real_server(self, server):
         real_server = RealServer(self.get_virtual_service_info,
                                  server.get('Addr', None),
                                  server.get('Port', None))
@@ -450,12 +453,6 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         real_server.enable = server.get('Enable', None)
         real_server.weight = server.get('Weight', None)
         real_server.limit = server.get('Limit', None)
-        print("##########")
-        print(repr(server))
-        print("##########")
-        print("##########")
-        print(repr(real_server))
-        print("##########")
         return real_server
 
 
@@ -468,16 +465,19 @@ class RealServer(HttpClient, KempBaseObjectModel):
             self.vs = loadmaster_virt_service_info["vs"]
         except KeyError:
             raise RealServerMissingVirtualServiceInfo("vs")
+
         self.port = loadmaster_virt_service_info.get("port", None)
         self.prot = loadmaster_virt_service_info.get("prot", None)
         try:
             self.endpoint = loadmaster_virt_service_info["endpoint"]
         except KeyError:
             raise RealServerMissingLoadmasterInfo("endpoint")
+
         try:
             self.ip_address = loadmaster_virt_service_info["ip_address"]
         except KeyError:
             raise RealServerMissingLoadmasterInfo("ip_address")
+
         super(RealServer, self).__init__()
 
     def __str__(self):
