@@ -106,22 +106,26 @@ class LoadMasterParameterError(Exception):
         super(LoadMasterParameterError, self).__init__(msg)
 
 
-class VirtualServiceMissingLoadmasterInfo(Exception):
+class MissingInfo(Exception):
+    service = 'My service'
+    param_name = 'parameter_name'
+
     def __init__(self, param):
-        msg = ("Virtual service is missing the LoadMaster parameter "
-               "'{}'").format(param)
-        super(VirtualServiceMissingLoadmasterInfo, self).__init__(msg)
+        msg = ("{} is missing the {} parameter "
+               "'{}'").format(self.service, self.param_name, param)
+        super(MissingInfo, self).__init__(msg)
 
 
-class RealServerMissingLoadmasterInfo(Exception):
-    def __init__(self, param):
-        msg = ("Virtual service is missing the LoadMaster parameter "
-               "'{}'").format(param)
-        super(RealServerMissingLoadmasterInfo, self).__init__(msg)
+class VirtualServiceMissingLoadmasterInfo(MissingInfo):
+    service = 'Virtual service'
+    param_name = 'LoadMaster'
 
 
-class RealServerMissingVirtualServiceInfo(Exception):
-    def __init__(self, param):
-        msg = ("Virtual service is missing the LoadMaster parameter "
-               "'{}'").format(param)
-        super(RealServerMissingVirtualServiceInfo, self).__init__(msg)
+class RealServerMissingLoadmasterInfo(MissingInfo):
+    service = 'Real server'
+    param_name = 'LoadMaster'
+
+
+class RealServerMissingVirtualServiceInfo(MissingInfo):
+    service = 'Real server'
+    param_name = 'Virtual service'
